# -*- coding: utf-8 -*-

"""INTERFACE ROUTINES.

This module contains submodules for error handling, logging and IO interaction.

:Author: Samuel Farrens <samuel.farrens@cea.fr>

"""

__all__ = ['errors', 'log']
